@@ -20,7 +20,7 @@ use Exporter;
 use Carp;
 
 our @ISA     = qw(Exporter);
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 #
 # NOTE: this module is a light weight re-implementation of XML::Writer. See
@@ -77,9 +77,10 @@ sub startTag {
 
     print { $self->{_fh} } "<$tag";
 
-    while (@attributes) {
-        my $key = shift @attributes;
+    while ( @attributes ) {
+        my $key   = shift @attributes;
         my $value = shift @attributes;
+        $value = _escape_xml_chars( $value );
 
         print { $self->{_fh} } qq( $key="$value");
     }
@@ -117,9 +118,10 @@ sub emptyTag {
 
     print { $self->{_fh} } "<$tag";
 
-    while (@attributes) {
-        my $key = shift @attributes;
+    while ( @attributes ) {
+        my $key   = shift @attributes;
         my $value = shift @attributes;
+        $value = _escape_xml_chars( $value );
 
         print { $self->{_fh} } qq( $key="$value");
     }
@@ -146,22 +148,15 @@ sub dataElement {
 
     print { $self->{_fh} } "<$tag";
 
-    while (@attributes) {
-        my $key = shift @attributes;
+    while ( @attributes ) {
+        my $key   = shift @attributes;
         my $value = shift @attributes;
+        $value = _escape_xml_chars( $value );
 
         print { $self->{_fh} } qq( $key="$value");
     }
 
-    # Escape XML characters.
-    if ( $data =~ m/[&<>"]/ ) {
-        for ( $data ) {
-            s/&/&amp;/g;
-            s/</&lt;/g;
-            s/>/&gt;/g;
-            s/"/&quot;/g;
-        }
-    }
+    $data = _escape_xml_chars( $data );
 
     print { $self->{_fh} } ">";
     print { $self->{_fh} } $data;
@@ -169,6 +164,23 @@ sub dataElement {
 }
 
 
+###############################################################################
+#
+# characters()
+#
+# For compatibility with XML::Writer only.
+#
+sub characters {
+
+    my $self = shift;
+    my $data = shift;
+
+    $data = _escape_xml_chars( $data );
+
+    print { $self->{_fh} } $data;
+}
+
+
 ###############################################################################
 #
 # end()
@@ -179,6 +191,7 @@ sub end {
 
     my $self = shift;
 
+    print { $self->{_fh} } "\n";
 }
 
 
@@ -196,6 +209,29 @@ sub getOutput {
 }
 
 
+###############################################################################
+#
+# _escape_xml_chars()
+#
+# Escape XML characters.
+#
+sub _escape_xml_chars {
+
+    my $str = shift;
+
+    return $str if $str !~ m/[&<>"]/;
+
+    for ( $str ) {
+        s/&/&amp;/g;
+        s/</&lt;/g;
+        s/>/&gt;/g;
+        s/"/&quot;/g;
+    }
+
+    return $str;
+}
+
+
 1;
 
 
